;
var picto_lang_fr = "http://sciences.univ-lyon1.fr/images/drapeaux/fr.svg";
var picto_lang_en = "http://sciences.univ-lyon1.fr/images/drapeaux/en.svg";

var alternance_str = "(disponible en alternance)";
var str_anchor_prefix = "FST_LVL_";
var picto_size_small = 12;
var picto_size_medium = 24;

var papa_config = {
  delimiter: ";",
  quoteChar: '"',
  header: true,
  skipEmptyLines: true
};

function odf_mention_url(id){
  return "http://offre-de-formations.univ-lyon1.fr/mention-" +id +"/odf.html";
};

function strip_composante(str){
  var res = str.split("/")[1].trim();
  return res.replace(/dépt./gi,"Département");
};

/*generates a pair with icon and link*/
function infos_dpt(str){
  var picto = undefined ;
  var url = undefined;

  if (/Informatique/i.test(str)){
    picto = "http://sciences.univ-lyon1.fr/images/DPTINFON/defaut.gif";
    url = "http://fst-informatique.univ-lyon1.fr/";
  }
  if (/Biologie/i.test(str)){
    picto = "http://sciences.univ-lyon1.fr/images/BIOLOGIEN/defaut.gif";
    url = "http://fst-biologie.univ-lyon1.fr/";
  }
  if (/Chimie/i.test(str)){
    picto = "http://sciences.univ-lyon1.fr/images/CHIMIE-BIOCHIMIE/defaut.gif";
    url = "http://fst-chimie.univ-lyon1.fr/";
  }
  if (/.?lectrique/i.test(str)){
    picto = "http://sciences.univ-lyon1.fr/images/GEPN/defaut.gif";
    url = "http://fst-gep.univ-lyon1.fr/"
  }
  if (/Math.?matiques/i.test(str)){
    picto = "http://sciences.univ-lyon1.fr/images/MATHN/defaut.gif";
    url = "http://fst-mathematiques.univ-lyon1.fr/";
  }
  if (/M.?canique/i.test(str)){
    picto = "http://sciences.univ-lyon1.fr/images/MECAN/defaut.gif";
    url = "http://fst-meca.univ-lyon1.fr/";
  }
  if (/Physique/i.test(str)){
    picto = "http://sciences.univ-lyon1.fr/images/PHYSIQUEN/defaut.gif";
    url = "http://fst-physique.univ-lyon1.fr/";
  }

  return {picto:picto, url:url};
};

function group_by_field(arr, fields){
  /*sort the array according to an array of fields*/
  arr.sort(function(a,b){
    var str_a = "";
    var str_b = "";
    fields.forEach(function (field){
      str_a = str_a.concat(a[field]);
      str_b = str_b.concat(b[field]);
    });
    return (str_a.localeCompare(str_b));
  });

  var result = [];
  var curr_fields = {};
  var idx = -1;
  var new_group = false;
  
  /*group by function create one group per unique key
  into a structure {field1:val1, field2:val2, ..., values:[]}
  where fields = [field1, field2, ...] */
  arr.forEach(function(line){
    new_group = false;
    /*tests if one of the fields is new*/
    fields.forEach(function(field){
      if (line[field] !== curr_fields[field])
        new_group = new_group || true;
      curr_fields[field]=line[field];
    });

    /*we create a new group when needed*/
    if(new_group){
      result[++idx] = {};
      fields.forEach(function(field){
        result[idx][field] = curr_fields[field];
      });
            
      result[idx]["values"] = [];
    }
    /* we add current line to the current group*/
    result[idx].values.push(line);
  });

  return result;
};

/*generate header menu with anchors*/
function render_odf_menu(data, labelFormation, fields_lvl_1){
  fields_lvl_1 =  fields_lvl_1 || ["COMPOSANTE"];
  labelFormation = labelFormation || "Formations";
  var result = "";
  var first_lvl = group_by_field(data.data, fields_lvl_1);
  /*generate # link for all groups*/

  result += "<ul>";
  first_lvl.forEach(function(first, idx_first){
    result += '<li data-type="departement"><img src="' + infos_dpt(first["COMPOSANTE"]).picto + '" width="' + picto_size_small + '">&nbsp;<a href="#' + str_anchor_prefix+idx_first + '">' + labelFormation + ' du ' + strip_composante(first["COMPOSANTE"]).toLowerCase() + '</a></li>';
  });
  result += "</ul>";  

  return result;
};

/*group by the csv file according to two levels
  the hierarchy is as follows:
  <h3> 1st level valule #1<h3>
    <ul> 
      <li><h4>2nd level value #1.#1</h4>
        <ul>
          <li>#1.#1 line1</li>
          <li>#1.#1 line2</li>
          ...
        </ul>
      </li>
      <li><h4>2nd level value #1.#2</h4>
        <ul>
          <li>#1.#2 line1</li>
          <li>#1.#2 line2</li>
          ...
        </ul>
      </li>
    </ul>
  <h3> 1st level valule #2<h3>
  ...
*/
function render_odf_group(data, fields_lvl_1, render_lvl_1, fields_lvl_2, render_lvl_2, render_line){
  fields_lvl_1 = fields_lvl_1 || ["COMPOSANTE"];
  fields_lvl_2 = fields_lvl_2 || ["DIPLOME", "MEN_TITLE", "MEN_ID"];
  var result = "";
  var first_lvl = group_by_field(data.data, fields_lvl_1);

  /*for each first level*/
  first_lvl.forEach(function(lvl_1_itm, lvl_1_idx){
    result += render_lvl_1(lvl_1_itm, lvl_1_idx);
    result += '<ul>'; 
    /*for each second level*/
    var second_lvl = group_by_field(lvl_1_itm.values, fields_lvl_2);
    second_lvl.forEach(function(lvl_2_itm, lvl_2_idx){
        result += '<li>'; 
        result += render_lvl_2(lvl_2_itm, lvl_2_idx);
        /*FOR EACH LINE*/
        result += '<ul>'; 
        lvl_2_itm.values.forEach(function(itm, idx){
          result += render_line(itm, idx);
        });
        result += '</ul>'; 
        result += '</li>'; 
    });
    result += '</ul>';
  });

  return result;
};

function render_composante(itm, idx){
  var composante = strip_composante(itm["COMPOSANTE"]); 
  var infos = infos_dpt(composante);
    return '<h3><img src="' + infos.picto + '" width="' + picto_size_medium + '">&nbsp;' + composante + '&nbsp;<a id="' + str_anchor_prefix+idx + '" href="' + infos.url + '" target="_blank">&#128279;</a></h3>';
}

function render_diplome(itm){
  return '<h4><a href="' + odf_mention_url(itm["MEN_ID"]) + '" target="_blank">' + itm["DIPLOME"] + " " + itm["MEN_TITLE"] +'</a></h4>';
}

function render_parcours(itm){
  var result = "";
    result += '<li data-type="parcours">';
    result += '<a href="' + itm["URL_PARCOURS"] + '" target="_blank">';
    result += 'Parcours&nbsp;' + itm["PAR_TITLE"];
    result += (itm["ALTERNANCE"]==1)?" "+alternance_str:"";
    result += '</a>';
    if (itm["ANGLAIS"] == 1)
      result += '&nbsp;<img src="' + picto_lang_en + '" width="' + picto_size_small + '">';
    if (itm["FRANCAIS"] == 1)
      result += '&nbsp;<img src="' + picto_lang_fr + '" width="' + picto_size_small + '">';
    result += '</li>';
  return result;
}

/*generate menu and values*/
function render_odf(data, label_formation, fields_lvl_1, render_lvl_1, fields_lvl_2, render_lvl_2, render_line){
  var str = "";
  str += render_odf_menu(data, label_formation, fields_lvl_1);
  str += render_odf_group(data, fields_lvl_1, render_lvl_1, fields_lvl_2, render_lvl_2, render_line);
  return str;
};


;$(document).ready(function(){
  var content = Papa.parse($("#odf_fst_all")[0].innerHTML, papa_config);
  $("#odf_fst_all").html(render_odf(content, "Formations",["COMPOSANTE"],render_composante,["DIPLOME",,"MEN_ID","MEN_TITLE"],render_diplome,render_parcours));
});
